==> idev-0.1.0.tar.gz: lib/irouter/examples/use_rail.dart <==
import 'package:flutter/material.dart';
import '../../irouter.dart';
import 'screens/first.dart';
import 'screens/second.dart';

void main() {
  runApp(const App());
}

class App extends StatefulWidget {
  const App({Key? key}) : super(key: key);

  @override
  _AppState createState() => _AppState();
}

class _AppState extends State<App> {
  final _navigatorKey = GlobalKey<NavigatorState>();
  late final IRouter _routeState;
  late final IRouterDelegate _routerDelegate;
  late final IRouteParser _routeParser;
  late final List<Page<dynamic>> _pages;

  @override
  void initState() {
    _routeParser = IRouteParser(
      routes: {
        '/': (BuildContext context, Map<String, dynamic> params) =>
            const FirstPage(),
        '/second': (context, params) => const SecondPage(),
      },
      initialRoute: '/',
    );

    _routeState = IRouter(_routeParser);
    const _scaffoldKey = ValueKey('App scaffold');

    _pages = [
      const MaterialPage<void>(
        key: _scaffoldKey,
        child: HomePage(),
      ),
    ];

    _routerDelegate = IRouterDelegate(
      routeState: _routeState,
      navigatorKey: _navigatorKey,
      builder: (context) =>
          IRootNavigator(navigatorKey: _navigatorKey, pages: _pages),
    );

    super.initState();
  }

  @override
  Widget build(BuildContext context) => IRouterScope(
        notifier: _routeState,
        child: MaterialApp.router(
          routerDelegate: _routerDelegate,
          routeInformationParser: _routeParser,
          theme: ThemeData(
            pageTransitionsTheme: const PageTransitionsTheme(
              builders: {
                TargetPlatform.android: FadeUpwardsPageTransitionsBuilder(),
                TargetPlatform.iOS: CupertinoPageTransitionsBuilder(),
                TargetPlatform.linux: FadeUpwardsPageTransitionsBuilder(),
                TargetPlatform.macOS: CupertinoPageTransitionsBuilder(),
                TargetPlatform.windows: FadeUpwardsPageTransitionsBuilder(),
              },
            ),
          ),
        ),
      );

  @override
  void dispose() {
    _routeState.dispose();
    _routerDelegate.dispose();
    super.dispose();
  }
}

class HomePage extends StatefulWidget {
  const HomePage({Key? key, this.title}) : super(key: key);

  final String? title;

  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  IRouter? routeState;
  String? userId;

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    //_pageController.dispose();

    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    routeState ??= IRouterScope.of(context, listen: true);
    final _selectedIndex = routeState!.getPageId();

    debugPrint('home:build');
    var width = MediaQuery.of(context).size.width;
    bool _isExtended = false;
    if (width > 600) _isExtended = true;

    return Scaffold(
      appBar: AppBar(
        title: const Text('use IRouter in NavigationRail'),
      ),
      body: Row(
        children: <Widget>[
          Padding(
            padding: const EdgeInsets.only(bottom: 10.0),
            child: Column(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Expanded(
                    child: NavigationRail(
                      minWidth: 56,
                      extended: _isExtended,
                      selectedIndex: _selectedIndex,
                      onDestinationSelected: (int index) {
                        routeState!.to(
                            routeState!.tabs['ipage']![index].currentUrl,
                            index);
                        setState(() {});
                      },
                      //leading: const Center(child: Text('leading')),
                      //trailing: const Center(child: Text('trailing')),
                      //groupAlignment: 1,
                      labelType: NavigationRailLabelType.none,
                      destinations: const <NavigationRailDestination>[
                        NavigationRailDestination(
                          icon: Icon(Icons.favorite_border),
                          selectedIcon: Icon(Icons.favorite),
                          label: Text('First'),
                        ),
                        NavigationRailDestination(
                          icon: Icon(Icons.bookmark_border),
                          selectedIcon: Icon(Icons.book),
                          label: Text('Second'),
                        ),
                      ],
                    ),
                  ),
                ]),
          ),
          Expanded(
              child: ITabNavigator(
            urls: const ['/', '/second'],
            index: _selectedIndex,
            tabId: 'ipage',
          )),
        ],
      ),
    );
  }
}

==> idev-0.1.1.tar.gz: lib/irouter/examples/use_rail.dart <==
import 'package:flutter/material.dart';
import '../../irouter.dart';
import 'screens/first.dart';
import 'screens/second.dart';

void main() {
  runApp(const App());
}

class App extends StatefulWidget {
  const App({Key? key}) : super(key: key);

  @override
  _AppState createState() => _AppState();
}

class _AppState extends State<App> {
  final _navigatorKey = GlobalKey<NavigatorState>();
  late final IRouter _routeState;
  late final IRouterDelegate _routerDelegate;
  late final IRouteParser _routeParser;
  late final List<Page<dynamic>> _pages;

  @override
  void initState() {
    _routeParser = IRouteParser(
      routes: {
        '/': (BuildContext context, Map<String, dynamic> params) =>
            const FirstPage(),
        '/second': (context, params) => const SecondPage(),
      },
      initialRoute: '/',
    );

    _routeState = IRouter(_routeParser);
    const _scaffoldKey = ValueKey('App scaffold');

    _pages = [
      const MaterialPage<void>(
        key: _scaffoldKey,
        child: HomePage(),
      ),
    ];

    _routerDelegate = IRouterDelegate(
      routeState: _routeState,
      navigatorKey: _navigatorKey,
      builder: (context) =>
          IRootNavigator(navigatorKey: _navigatorKey, pages: _pages),
    );

    super.initState();
  }

  @override
  Widget build(BuildContext context) => IRouter.provider(
        _routeState,
        MaterialApp.router(
          routerDelegate: _routerDelegate,
          routeInformationParser: _routeParser,
          theme: ThemeData(
            pageTransitionsTheme: const PageTransitionsTheme(
              builders: {
                TargetPlatform.android: FadeUpwardsPageTransitionsBuilder(),
                TargetPlatform.iOS: CupertinoPageTransitionsBuilder(),
                TargetPlatform.linux: FadeUpwardsPageTransitionsBuilder(),
                TargetPlatform.macOS: CupertinoPageTransitionsBuilder(),
                TargetPlatform.windows: FadeUpwardsPageTransitionsBuilder(),
              },
            ),
          ),
        ),
      );

  @override
  void dispose() {
    _routeState.dispose();
    _routerDelegate.dispose();
    super.dispose();
  }
}

class HomePage extends StatefulWidget {
  const HomePage({Key? key, this.title}) : super(key: key);

  final String? title;

  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  IRouter? routeState;
  String? userId;

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    //_pageController.dispose();

    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    routeState ??= IRouter.of(context, listen: true);
    final _selectedIndex = routeState!.getPageId();

    debugPrint('home:build');
    var width = MediaQuery.of(context).size.width;
    bool _isExtended = false;
    if (width > 600) _isExtended = true;

    return Scaffold(
      // appBar: AppBar(
      //   title: const Text('use IRouter in NavigationRail'),
      // ),
      body: Row(
        children: <Widget>[
          Padding(
            padding: const EdgeInsets.only(bottom: 10.0),
            child: Column(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Expanded(
                    child: NavigationRail(
                      minWidth: 56,
                      extended: _isExtended,
                      selectedIndex: _selectedIndex,
                      onDestinationSelected: (int index) {
                        IRouter.push(
                            context,
                            routeState!.tabs['ipage']![index].currentUrl,
                            index);
                        // routeState!.to(
                        //     routeState!.tabs['ipage']![index].currentUrl,
                        //     index);
                        setState(() {});
                      },
                      //leading: const Center(child: Text('leading')),
                      //trailing: const Center(child: Text('trailing')),
                      //groupAlignment: 1,
                      labelType: NavigationRailLabelType.none,
                      destinations: const <NavigationRailDestination>[
                        NavigationRailDestination(
                          icon: Icon(Icons.favorite_border),
                          selectedIcon: Icon(Icons.favorite),
                          label: Text('First'),
                        ),
                        NavigationRailDestination(
                          icon: Icon(Icons.bookmark_border),
                          selectedIcon: Icon(Icons.book),
                          label: Text('Second'),
                        ),
                      ],
                    ),
                  ),
                ]),
          ),
          Expanded(
              child: ITabNavigator(
            urls: const ['/', '/second'],
            index: _selectedIndex,
            tabId: 'ipage',
          )),
        ],
      ),
    );
  }
}
